pub struct PublisherPartialBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl PublisherPartialBuilder
impl PublisherPartialBuilder
Sourcepub fn set_message_count_threshold(
self,
threshold: u32,
) -> PublisherPartialBuilder
pub fn set_message_count_threshold( self, threshold: u32, ) -> PublisherPartialBuilder
Sets the message count threshold for batching.
The publisher will send a batch of messages when the number of messages in the batch reaches this threshold.
Example
let publisher = client
.publisher("projects/my-project/topics/my-topic")
.set_message_count_threshold(100)
.build();Sourcepub fn set_byte_threshold(self, threshold: u32) -> PublisherPartialBuilder
pub fn set_byte_threshold(self, threshold: u32) -> PublisherPartialBuilder
Sets the byte threshold for batching.
The publisher will send a batch of messages when the total size of the messages in the batch reaches this threshold.
Example
let publisher = client
.publisher("projects/my-project/topics/my-topic")
.set_byte_threshold(1024) // 1 KiB
.build();Sourcepub fn set_delay_threshold(self, threshold: Duration) -> PublisherPartialBuilder
pub fn set_delay_threshold(self, threshold: Duration) -> PublisherPartialBuilder
Sets the delay threshold for batching.
The publisher will wait a maximum of this amount of time before sending a batch of messages.
Example
let publisher = client
.publisher("projects/my-project/topics/my-topic")
.set_delay_threshold(Duration::from_millis(50))
.build();Trait Implementations
Sourceimpl Clone for PublisherPartialBuilder
impl Clone for PublisherPartialBuilder
Sourcefn clone(&self) -> PublisherPartialBuilder
fn clone(&self) -> PublisherPartialBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for PublisherPartialBuilder
impl !UnwindSafe for PublisherPartialBuilder
impl Freeze for PublisherPartialBuilder
impl Send for PublisherPartialBuilder
impl Sync for PublisherPartialBuilder
impl Unpin for PublisherPartialBuilder
impl UnsafeUnpin for PublisherPartialBuilder