Subscriber

Struct Subscriber 

pub struct Subscriber { /* private fields */ }
A Subscriber client for the Cloud Pub/Sub API.

Use this client to receive messages from a pull subscription on a topic.

Example

let client = Subscriber::builder().build().await?;
let mut stream = client
    .subscribe("projects/my-project/subscriptions/my-subscription")
    .build();
while let Some((m, h)) = stream.next().await.transpose()? {
    println!("Received message m={m:?}");
    h.ack();
}

Ordered Delivery

The subscriber returns messages in order if ordered delivery is enabled on the subscription. The client provides the same guarantees as the service.

For more details on how the service works, see:

Exactly-once Delivery

The subscriber supports exactly-once delivery.

If you enable exactly-once delivery for a subscription, your application can be opinionated about the delivery type, by destructuring the handler into its Handler::ExactlyOnce branch.

use google_cloud_pubsub::subscriber::MessageStream;
use google_cloud_pubsub::subscriber::handler::Handler;
async fn exactly_once_stream(mut stream: MessageStream) -> anyhow::Result<()> {
  while let Some((m, Handler::ExactlyOnce(h))) = stream.next().await.transpose()? {
      println!("Received message m={m:?}");

      // Await the result of the ack. Typically you would not block the loop
      // with an `await` point like this.
      h.confirmed_ack().await?;
  }
  unreachable!("Oops, my subscription must have at-least-once semantics")
}

You should not change the delivery type of a subscription midstream. If you do, the subscriber will honor the delivery setting at the time each message was received.

Configuration

To configure a Subscriber use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include:

Pooling and Cloning

Subscriber holds a connection pool internally, it is advised to create one and then reuse it. You do not need to wrap Subscriber in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Subscriber

pub fn builder() -> ClientBuilder

Returns a builder for Subscriber.

Example
let client = Subscriber::builder().build().await?;
pub fn subscribe<T>(&self, subscription: T) -> Subscribe
where T: Into<String>,

Receive messages from a subscription.

The subscription is the full name, in the format of projects/*/subscriptions/*.

Example
let mut stream = client
    .subscribe("projects/my-project/subscriptions/my-subscription")
    .build();
while let Some((m, h)) = stream.next().await.transpose()? {
    println!("Received message m={m:?}");
    h.ack();
}