Module error

Module error 

Custom errors for the Cloud Pub/Sub clients.

Enums

AckError
Represents an error that can occur when acking or nacking a message.
PublishError
Represents an error that can occur when publishing a message.