#[non_exhaustive]pub enum AckError {
LeaseExpired,
#[non_exhaustive] Rpc {
source: Arc<Error>,
},
ShutdownBeforeAck,
Shutdown(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Represents an error that can occur when acknowledging a message.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LeaseExpired
The message’s lease expired before the client could acknowledge it.
The message has not been acknowledged, and will be redelivered, maybe to another client.
#[non_exhaustive]Rpc
The underlying RPC failed.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ShutdownBeforeAck
Lease management shutdown before the client could acknowledge the message.
The client did not acknowledge the message. The service will redeliver message.
Shutdown(Box<dyn Error + Send + Sync + 'static>)
Error during shutdown.
The result of the acknowledgement is unknown. The service may or may not redeliver the message.