Module model

Module model 

The messages and enums that are part of this client library.

Modules

ai_inference
Defines additional types related to AIInference.
big_query_config
Defines additional types related to BigQueryConfig.
bigtable_config
Defines additional types related to BigtableConfig.
cloud_storage_config
Defines additional types related to CloudStorageConfig.
ingestion_data_source_settings
Defines additional types related to IngestionDataSourceSettings.
message_transform
Defines additional types related to MessageTransform.
platform_logs_settings
Defines additional types related to PlatformLogsSettings.
push_config
Defines additional types related to PushConfig.
schema
Defines additional types related to Schema.
seek_request
Defines additional types related to SeekRequest.
subscription
Defines additional types related to Subscription.
topic
Defines additional types related to Topic.
validate_message_request
Defines additional types related to ValidateMessageRequest.

Structs

AIInference
Configuration for making inference requests against Vertex AI models.
BigQueryConfig
Configuration for a BigQuery subscription.
BigtableConfig
Configuration for a Bigtable subscription. The Pub/Sub message will be written to a Bigtable row as follows:
CloudStorageConfig
Configuration for a Cloud Storage subscription.
CommitSchemaRequest
Request for CommitSchema method.
CreateSchemaRequest
Request for the CreateSchema method.
CreateSnapshotRequest
Request for the CreateSnapshot method.
DeadLetterPolicy
Dead lettering is done on a best effort basis. The same message might be dead lettered multiple times.
DeleteSchemaRequest
Request for the DeleteSchema method.
DeleteSchemaRevisionRequest
Request for the DeleteSchemaRevision method.
DeleteSnapshotRequest
Request for the DeleteSnapshot method.
DeleteSubscriptionRequest
Request for the DeleteSubscription method.
DeleteTopicRequest
Request for the DeleteTopic method.
DetachSubscriptionRequest
Request for the DetachSubscription method.
DetachSubscriptionResponse
Response for the DetachSubscription method. Reserved for future use.
ExpirationPolicy
A policy that specifies the conditions for resource expiration (i.e., automatic resource deletion).
GetSchemaRequest
Request for the GetSchema method.
GetSnapshotRequest
Request for the GetSnapshot method.
GetSubscriptionRequest
Request for the GetSubscription method.
GetTopicRequest
Request for the GetTopic method.
IngestionDataSourceSettings
Settings for an ingestion data source on a topic.
JavaScriptUDF
User-defined JavaScript function that can transform or filter a Pub/Sub message.
ListSchemaRevisionsRequest
Request for the ListSchemaRevisions method.
ListSchemaRevisionsResponse
Response for the ListSchemaRevisions method.
ListSchemasRequest
Request for the ListSchemas method.
ListSchemasResponse
Response for the ListSchemas method.
ListSnapshotsRequest
Request for the ListSnapshots method.
ListSnapshotsResponse
Response for the ListSnapshots method.
ListSubscriptionsRequest
Request for the ListSubscriptions method.
ListSubscriptionsResponse
Response for the ListSubscriptions method.
ListTopicSnapshotsRequest
Request for the ListTopicSnapshots method.
ListTopicSnapshotsResponse
Response for the ListTopicSnapshots method.
ListTopicSubscriptionsRequest
Request for the ListTopicSubscriptions method.
ListTopicSubscriptionsResponse
Response for the ListTopicSubscriptions method.
ListTopicsRequest
Request for the ListTopics method.
ListTopicsResponse
Response for the ListTopics method.
Message
A message that is published by publishers and consumed by subscribers. The message must contain either a non-empty data field or at least one attribute. Note that client libraries represent this object differently depending on the language. See the corresponding client library documentation for more information. See [quotas and limits] (https://cloud.google.com/pubsub/quotas) for more information about message limits.
MessageStoragePolicy
A policy constraining the storage of messages published to the topic.
MessageTransform
All supported message transforms types.
ModifyPushConfigRequest
Request for the ModifyPushConfig method.
PlatformLogsSettings
Settings for Platform Logs produced by Pub/Sub.
PushConfig
Configuration for a push delivery endpoint.
RetryPolicy
A policy that specifies how Pub/Sub retries message delivery.
RollbackSchemaRequest
Request for the RollbackSchema method.
Schema
A schema resource.
SchemaSettings
Settings for validating messages published against a schema.
SeekRequest
Request for the Seek method.
SeekResponse
Response for the Seek method (this response is empty).
Snapshot
A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.
Subscription
A subscription resource. If none of push_config, bigquery_config, or cloud_storage_config is set, then the subscriber will pull and ack messages using API methods. At most one of these fields may be set.
Topic
A topic resource.
UpdateSnapshotRequest
Request for the UpdateSnapshot method.
UpdateSubscriptionRequest
Request for the UpdateSubscription method.
UpdateTopicRequest
Request for the UpdateTopic method.
ValidateMessageRequest
Request for the ValidateMessage method.
ValidateMessageResponse
Response for the ValidateMessage method. Empty for now.
ValidateSchemaRequest
Request for the ValidateSchema method.
ValidateSchemaResponse
Response for the ValidateSchema method. Empty for now.

Enums

Encoding
Possible encoding types for messages.
SchemaView
View of Schema object fields to be returned by GetSchema and ListSchemas.