#[non_exhaustive]pub enum State {
Unspecified,
Active,
NotFound,
AppProfileMisconfigured,
PermissionDenied,
SchemaMismatch,
InTransitLocationRestriction,
VertexAiLocationRestriction,
UnknownValue(UnknownValue),
}Expand description
Possible states for a Bigtable subscription. Note: more states could be added in the future. Please code accordingly.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. This value is unused.
Active
The subscription can actively send messages to Bigtable.
NotFound
Cannot write to Bigtable because the instance, table, or app profile does not exist.
AppProfileMisconfigured
Cannot write to Bigtable because the app profile is not configured for single-cluster routing.
PermissionDenied
Cannot write to Bigtable because of permission denied errors. This can happen if:
- The Pub/Sub service agent has not been granted the appropriate Bigtable IAM permission bigtable.tables.mutateRows
- The bigtable.googleapis.com API is not enabled for the project (instructions)
SchemaMismatch
Cannot write to Bigtable because of a missing column family (“data”) or if there is no structured row key for the subscription name + message ID.
InTransitLocationRestriction
Cannot write to the destination because enforce_in_transit is set to true and the destination locations are not in the allowed regions.
VertexAiLocationRestriction
Cannot write to Bigtable because the table is not in the same location as
where Vertex AI models used in message_transforms are deployed.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations