Defines additional types related to CloudStorageConfig.
Structs
- Avro
Config - Configuration for writing message data in Avro format. Message payloads and metadata will be written to files as an Avro binary.
- Text
Config - Configuration for writing message data in text format. Message payloads will be written to files as raw text, separated by a newline.
Enums
- Output
Format - Defaults to text format.
- State
- Possible states for a Cloud Storage subscription.