Module cloud_storage

Module cloud_storage 

Defines additional types related to CloudStorage.

Structs

AvroFormat
Configuration for reading Cloud Storage data in Avro binary format. The bytes of each object will be set to the data field of a Pub/Sub message.
PubSubAvroFormat
Configuration for reading Cloud Storage data written via Cloud Storage subscriptions. The data and attributes fields of the originally exported Pub/Sub message will be restored when publishing.
TextFormat
Configuration for reading Cloud Storage data in text format. Each line of text as specified by the delimiter will be set to the data field of a Pub/Sub message.

Enums

InputFormat
Defaults to text format.
State
Possible states for ingestion from Cloud Storage.