AwsMsk

#[non_exhaustive]
pub struct AwsMsk { pub state: State, pub cluster_arn: String, pub topic: String, pub aws_role_arn: String, pub gcp_service_account: String, /* private fields */ }
Ingestion settings for Amazon MSK.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
state: State

Output only. An output-only field that indicates the state of the Amazon MSK ingestion source.

cluster_arn: String

Required. The Amazon Resource Name (ARN) that uniquely identifies the cluster.

topic: String

Required. The name of the topic in the Amazon MSK cluster that Pub/Sub will import from.

aws_role_arn: String

Required. AWS role ARN to be used for Federated Identity authentication with Amazon MSK. Check the Pub/Sub docs for how to set up this role and the required permissions that need to be attached to it.

gcp_service_account: String

Required. The GCP service account to be used for Federated Identity authentication with Amazon MSK (via a AssumeRoleWithWebIdentity call for the provided role). The aws_role_arn must be set up with accounts.google.com:sub equals to this service account number.

Implementations

Source

impl AwsMsk

pub fn new() -> Self

Creates a new default instance.

pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::aws_msk::State;
let x0 = AwsMsk::new().set_state(State::Active);
let x1 = AwsMsk::new().set_state(State::MskPermissionDenied);
let x2 = AwsMsk::new().set_state(State::PublishPermissionDenied);
pub fn set_cluster_arn<T: Into<String>>(self, v: T) -> Self

Sets the value of cluster_arn.

Example
let x = AwsMsk::new().set_cluster_arn("example");
pub fn set_topic<T: Into<String>>(self, v: T) -> Self

Sets the value of topic.

Example
let x = AwsMsk::new().set_topic(format!("projects/{project_id}/topics/{topic_id}"));
pub fn set_aws_role_arn<T: Into<String>>(self, v: T) -> Self

Sets the value of aws_role_arn.

Example
let x = AwsMsk::new().set_aws_role_arn("example");
pub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self

Sets the value of gcp_service_account.

Example
let x = AwsMsk::new().set_gcp_service_account("example");