AzureEventHubs

Struct AzureEventHubs 

#[non_exhaustive]
pub struct AzureEventHubs { pub state: State, pub resource_group: String, pub namespace: String, pub event_hub: String, pub client_id: String, pub tenant_id: String, pub subscription_id: String, pub gcp_service_account: String, /* private fields */ }
Ingestion settings for Azure Event Hubs.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
state: State

Output only. An output-only field that indicates the state of the Event Hubs ingestion source.

resource_group: String

Optional. Name of the resource group within the azure subscription.

namespace: String

Optional. The name of the Event Hubs namespace.

event_hub: String

Optional. The name of the Event Hub.

client_id: String

Optional. The client id of the Azure application that is being used to authenticate Pub/Sub.

tenant_id: String

Optional. The tenant id of the Azure application that is being used to authenticate Pub/Sub.

subscription_id: String

Optional. The Azure subscription id.

gcp_service_account: String

Optional. The GCP service account to be used for Federated Identity authentication.

Implementations

Source

impl AzureEventHubs

pub fn new() -> Self

pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::azure_event_hubs::State;
let x0 = AzureEventHubs::new().set_state(State::Active);
let x1 = AzureEventHubs::new().set_state(State::EventHubsPermissionDenied);
let x2 = AzureEventHubs::new().set_state(State::PublishPermissionDenied);
pub fn set_resource_group<T: Into<String>>(self, v: T) -> Self

Sets the value of resource_group.

Example
let x = AzureEventHubs::new().set_resource_group("example");
pub fn set_namespace<T: Into<String>>(self, v: T) -> Self

Sets the value of namespace.

Example
let x = AzureEventHubs::new().set_namespace("example");
pub fn set_event_hub<T: Into<String>>(self, v: T) -> Self

Sets the value of event_hub.

Example
let x = AzureEventHubs::new().set_event_hub("example");
pub fn set_client_id<T: Into<String>>(self, v: T) -> Self

Sets the value of client_id.

Example
let x = AzureEventHubs::new().set_client_id("example");
pub fn set_tenant_id<T: Into<String>>(self, v: T) -> Self

Sets the value of tenant_id.

Example
let x = AzureEventHubs::new().set_tenant_id("example");
pub fn set_subscription_id<T: Into<String>>(self, v: T) -> Self

Sets the value of subscription_id.

Example
let x = AzureEventHubs::new().set_subscription_id("example");
pub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self

Sets the value of gcp_service_account.

Example
let x = AzureEventHubs::new().set_gcp_service_account("example");