CloudStorage

Struct CloudStorage 

#[non_exhaustive]
pub struct CloudStorage { pub state: State, pub bucket: String, pub minimum_object_create_time: Option<Timestamp>, pub match_glob: String, pub input_format: Option<InputFormat>, /* private fields */ }
Ingestion settings for Cloud Storage.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
state: State

Output only. An output-only field that indicates the state of the Cloud Storage ingestion source.

bucket: String

Optional. Cloud Storage bucket. The bucket name must be without any prefix like “gs://”. See the [bucket naming requirements] (https://cloud.google.com/storage/docs/buckets#naming).

minimum_object_create_time: Option<Timestamp>

Optional. Only objects with a larger or equal creation timestamp will be ingested.

match_glob: String

Optional. Glob pattern used to match objects that will be ingested. If unset, all objects will be ingested. See the supported patterns.

input_format: Option<InputFormat>

Defaults to text format.

Implementations

Source

impl CloudStorage

pub fn new() -> Self

pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::cloud_storage::State;
let x0 = CloudStorage::new().set_state(State::Active);
let x1 = CloudStorage::new().set_state(State::CloudStoragePermissionDenied);
let x2 = CloudStorage::new().set_state(State::PublishPermissionDenied);
pub fn set_bucket<T: Into<String>>(self, v: T) -> Self

Sets the value of bucket.

Example
let x = CloudStorage::new().set_bucket("example");
pub fn set_minimum_object_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of minimum_object_create_time.

Example
use wkt::Timestamp;
let x = CloudStorage::new().set_minimum_object_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_minimum_object_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of minimum_object_create_time.

Example
use wkt::Timestamp;
let x = CloudStorage::new().set_or_clear_minimum_object_create_time(Some(Timestamp::default()/* use setters */));
let x = CloudStorage::new().set_or_clear_minimum_object_create_time(None::<Timestamp>);
pub fn set_match_glob<T: Into<String>>(self, v: T) -> Self

Sets the value of match_glob.

Example
let x = CloudStorage::new().set_match_glob("example");
pub fn set_input_format<T: Into<Option<InputFormat>>>(self, v: T) -> Self

Sets the value of input_format.

Note that all the setters affecting input_format are mutually exclusive.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::cloud_storage::TextFormat;
let x = CloudStorage::new().set_input_format(Some(
    google_cloud_pubsub::model::ingestion_data_source_settings::cloud_storage::InputFormat::TextFormat(TextFormat::default().into())));
pub fn text_format(&self) -> Option<&Box<TextFormat>>

The value of input_format if it holds a TextFormat, None if the field is not set or holds a different branch.

pub fn set_text_format<T: Into<Box<TextFormat>>>(self, v: T) -> Self

Sets the value of input_format to hold a TextFormat.

Note that all the setters affecting input_format are mutually exclusive.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::cloud_storage::TextFormat;
let x = CloudStorage::new().set_text_format(TextFormat::default()/* use setters */);
assert!(x.text_format().is_some());
assert!(x.avro_format().is_none());
assert!(x.pubsub_avro_format().is_none());
pub fn avro_format(&self) -> Option<&Box<AvroFormat>>

The value of input_format if it holds a AvroFormat, None if the field is not set or holds a different branch.

pub fn set_avro_format<T: Into<Box<AvroFormat>>>(self, v: T) -> Self

Sets the value of input_format to hold a AvroFormat.

Note that all the setters affecting input_format are mutually exclusive.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::cloud_storage::AvroFormat;
let x = CloudStorage::new().set_avro_format(AvroFormat::default()/* use setters */);
assert!(x.avro_format().is_some());
assert!(x.text_format().is_none());
assert!(x.pubsub_avro_format().is_none());
pub fn pubsub_avro_format(&self) -> Option<&Box<PubSubAvroFormat>>

The value of input_format if it holds a PubsubAvroFormat, None if the field is not set or holds a different branch.

pub fn set_pubsub_avro_format<T: Into<Box<PubSubAvroFormat>>>( self, v: T, ) -> Self

Sets the value of input_format to hold a PubsubAvroFormat.

Note that all the setters affecting input_format are mutually exclusive.

Example
use google_cloud_pubsub::model::ingestion_data_source_settings::cloud_storage::PubSubAvroFormat;
let x = CloudStorage::new().set_pubsub_avro_format(PubSubAvroFormat::default()/* use setters */);
assert!(x.pubsub_avro_format().is_some());
assert!(x.text_format().is_none());
assert!(x.avro_format().is_none());