#[non_exhaustive]pub enum Severity {
Unspecified,
Disabled,
Debug,
Info,
Warning,
Error,
UnknownValue(UnknownValue),
}Expand description
Severity levels of Platform Logs.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Default value. Logs level is unspecified. Logs will be disabled.
Disabled
Logs will be disabled.
Debug
Debug logs and higher-severity logs will be written.
Info
Info logs and higher-severity logs will be written.
Warning
Warning logs and higher-severity logs will be written.
Error
Only error logs will be written.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Severity::value or Severity::name.
Implementations