#[non_exhaustive]pub struct OidcToken {
pub service_account_email: String,
pub audience: String,
/* private fields */
}Expand description
Contains information needed for generating an OpenID Connect token.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_account_email: StringOptional. Service account email used for generating the OIDC token. For more information on setting up authentication, see Push subscriptions.
audience: StringOptional. Audience to be used when generating OIDC token. The audience claim identifies the recipients that the JWT is intended for. The audience value is a single case-sensitive string. Having multiple values (array) for the audience field is not supported. More info about the OIDC JWT token audience here: https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, the Push endpoint URL will be used.
Implementations