Module schema

Module schema 

Defines additional types related to Schema.

Enums

Configuration
The configuration of the schema. This field is mutually exclusive with the definition field above, meaning either definition or one of the fields below can be set in a valid Schema object.
Type
Possible schema definition types.