#[non_exhaustive]pub enum Configuration {
CompiledProtoSchema(Box<CompiledProtoSchema>),
}Expand description
The configuration of the schema.
This field is mutually exclusive with the definition field above, meaning
either definition or one of the fields below can be set in a valid Schema
object.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CompiledProtoSchema(Box<CompiledProtoSchema>)
Optional. Configuration for a schema provided as a pre-compiled Protocol
Buffer FileDescriptorSet. The type field above must be set to
PROTOCOL_BUFFER.