BigtableConfig

Struct BigtableConfig 

#[non_exhaustive]
pub struct BigtableConfig { pub table: String, pub app_profile_id: String, pub service_account_email: String, pub write_metadata: bool, pub state: State, /* private fields */ }
Configuration for a Bigtable subscription. The Pub/Sub message will be written to a Bigtable row as follows:

  • row key: subscription name and message ID delimited by #.
  • columns: message bytes written to a single column family “data” with an empty-string column qualifier.
  • cell timestamp: the message publish timestamp.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
table: String

Optional. The unique name of the table to write messages to.

Values are of the form projects/<project>/instances/<instance>/tables/<table>.

app_profile_id: String

Optional. The app profile to use for the Bigtable writes. If not specified, the “default” application profile will be used. The app profile must use single-cluster routing.

service_account_email: String

Optional. The service account to use to write to Bigtable. The subscription creator or updater that specifies this field must have iam.serviceAccounts.actAs permission on the service account. If not specified, the Pub/Sub service agent, service-{project_number}@gcp-sa-pubsub.iam.gserviceaccount.com, is used.

write_metadata: bool

Optional. When true, write the subscription name, message_id, publish_time, attributes, and ordering_key to additional columns in the table under the pubsub_metadata column family. The subscription name, message_id, and publish_time fields are put in their own columns while all other message properties (other than data) are written to a JSON object in the attributes column.

state: State

Output only. An output-only field that indicates whether or not the subscription can receive messages.

Implementations

Source

impl BigtableConfig

pub fn new() -> Self

pub fn set_table<T: Into<String>>(self, v: T) -> Self

Sets the value of table.

Example
let x = BigtableConfig::new().set_table("example");
pub fn set_app_profile_id<T: Into<String>>(self, v: T) -> Self

Sets the value of app_profile_id.

Example
let x = BigtableConfig::new().set_app_profile_id("example");
pub fn set_service_account_email<T: Into<String>>(self, v: T) -> Self

Sets the value of service_account_email.

Example
let x = BigtableConfig::new().set_service_account_email("example");
pub fn set_write_metadata<T: Into<bool>>(self, v: T) -> Self

Sets the value of write_metadata.

Example
let x = BigtableConfig::new().set_write_metadata(true);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_pubsub::model::bigtable_config::State;
let x0 = BigtableConfig::new().set_state(State::Active);
let x1 = BigtableConfig::new().set_state(State::NotFound);
let x2 = BigtableConfig::new().set_state(State::AppProfileMisconfigured);