#[non_exhaustive]pub struct ListTopicSnapshotsResponse {
pub snapshots: Vec<String>,
pub next_page_token: String,
/* private fields */
}Expand description
Response for the ListTopicSnapshots method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.snapshots: Vec<String>Optional. The names of the snapshots that match the request.
next_page_token: StringOptional. If not empty, indicates that there may be more snapshots that
match the request; this value should be passed in a new
ListTopicSnapshotsRequest to get more snapshots.
Implementations
Sourceimpl ListTopicSnapshotsResponse
impl ListTopicSnapshotsResponse
Sourcepub fn set_snapshots<T, V>(self, v: T) -> Self
pub fn set_snapshots<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListTopicSnapshotsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListTopicSnapshotsResponse
impl Clone for ListTopicSnapshotsResponse
Sourcefn clone(&self) -> ListTopicSnapshotsResponse
fn clone(&self) -> ListTopicSnapshotsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListTopicSnapshotsResponse
impl Debug for ListTopicSnapshotsResponse
Sourceimpl Default for ListTopicSnapshotsResponse
impl Default for ListTopicSnapshotsResponse
Sourcefn default() -> ListTopicSnapshotsResponse
fn default() -> ListTopicSnapshotsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListTopicSnapshotsResponse
impl Message for ListTopicSnapshotsResponse
Sourceimpl PartialEq for ListTopicSnapshotsResponse
impl PartialEq for ListTopicSnapshotsResponse
Sourcefn eq(&self, other: &ListTopicSnapshotsResponse) -> bool
fn eq(&self, other: &ListTopicSnapshotsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListTopicSnapshotsResponse