#[non_exhaustive]pub struct SeekRequest {
pub subscription: String,
pub target: Option<Target>,
/* private fields */
}Expand description
Request for the Seek method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subscription: StringRequired. The subscription to affect.
target: Option<Target>Implementations
Sourceimpl SeekRequest
impl SeekRequest
Sourcepub fn set_subscription<T: Into<String>>(self, v: T) -> Self
pub fn set_subscription<T: Into<String>>(self, v: T) -> Self
Sets the value of subscription.
Example
ⓘ
let x = SeekRequest::new().set_subscription(format!("projects/{project_id}/subscriptions/{subscription_id}"));Sourcepub fn set_target<T: Into<Option<Target>>>(self, v: T) -> Self
pub fn set_target<T: Into<Option<Target>>>(self, v: T) -> Self
Sourcepub fn time(&self) -> Option<&Box<Timestamp>>
pub fn time(&self) -> Option<&Box<Timestamp>>
The value of target
if it holds a Time, None if the field is not set or
holds a different branch.
Sourcepub fn snapshot(&self) -> Option<&String>
pub fn snapshot(&self) -> Option<&String>
The value of target
if it holds a Snapshot, None if the field is not set or
holds a different branch.
Sourcepub fn set_snapshot<T: Into<String>>(self, v: T) -> Self
pub fn set_snapshot<T: Into<String>>(self, v: T) -> Self