pub trait SchemaService:
Debug
+ Send
+ Sync {
Show 13 methods
// Provided methods
fn create_schema(
&self,
_req: CreateSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send { ... }
fn get_schema(
&self,
_req: GetSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send { ... }
fn list_schemas(
&self,
_req: ListSchemasRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSchemasResponse>>> + Send { ... }
fn list_schema_revisions(
&self,
_req: ListSchemaRevisionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSchemaRevisionsResponse>>> + Send { ... }
fn commit_schema(
&self,
_req: CommitSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send { ... }
fn rollback_schema(
&self,
_req: RollbackSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send { ... }
fn delete_schema_revision(
&self,
_req: DeleteSchemaRevisionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send { ... }
fn delete_schema(
&self,
_req: DeleteSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn validate_schema(
&self,
_req: ValidateSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ValidateSchemaResponse>>> + Send { ... }
fn validate_message(
&self,
_req: ValidateMessageRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ValidateMessageResponse>>> + Send { ... }
fn set_iam_policy(
&self,
_req: SetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send { ... }
fn get_iam_policy(
&self,
_req: GetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send { ... }
fn test_iam_permissions(
&self,
_req: TestIamPermissionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<TestIamPermissionsResponse>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::SchemaService.
Application developers may need to implement this trait to mock
client::SchemaService. In other use-cases, application developers only
use client::SchemaService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn create_schema(
&self,
_req: CreateSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send
fn create_schema( &self, _req: CreateSchemaRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Schema>>> + Send
Implements super::client::SchemaService::create_schema.
Sourcefn get_schema(
&self,
_req: GetSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send
fn get_schema( &self, _req: GetSchemaRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Schema>>> + Send
Implements super::client::SchemaService::get_schema.
Sourcefn list_schemas(
&self,
_req: ListSchemasRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSchemasResponse>>> + Send
fn list_schemas( &self, _req: ListSchemasRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListSchemasResponse>>> + Send
Implements super::client::SchemaService::list_schemas.
Sourcefn list_schema_revisions(
&self,
_req: ListSchemaRevisionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSchemaRevisionsResponse>>> + Send
fn list_schema_revisions( &self, _req: ListSchemaRevisionsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListSchemaRevisionsResponse>>> + Send
Sourcefn commit_schema(
&self,
_req: CommitSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send
fn commit_schema( &self, _req: CommitSchemaRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Schema>>> + Send
Implements super::client::SchemaService::commit_schema.
Sourcefn rollback_schema(
&self,
_req: RollbackSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send
fn rollback_schema( &self, _req: RollbackSchemaRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Schema>>> + Send
Implements super::client::SchemaService::rollback_schema.
Sourcefn delete_schema_revision(
&self,
_req: DeleteSchemaRevisionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Schema>>> + Send
fn delete_schema_revision( &self, _req: DeleteSchemaRevisionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Schema>>> + Send
Sourcefn delete_schema(
&self,
_req: DeleteSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_schema( &self, _req: DeleteSchemaRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Implements super::client::SchemaService::delete_schema.
Sourcefn validate_schema(
&self,
_req: ValidateSchemaRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ValidateSchemaResponse>>> + Send
fn validate_schema( &self, _req: ValidateSchemaRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ValidateSchemaResponse>>> + Send
Implements super::client::SchemaService::validate_schema.
Sourcefn validate_message(
&self,
_req: ValidateMessageRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ValidateMessageResponse>>> + Send
fn validate_message( &self, _req: ValidateMessageRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ValidateMessageResponse>>> + Send
Implements super::client::SchemaService::validate_message.
Sourcefn set_iam_policy(
&self,
_req: SetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send
fn set_iam_policy( &self, _req: SetIamPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Policy>>> + Send
Implements super::client::SchemaService::set_iam_policy.
Sourcefn get_iam_policy(
&self,
_req: GetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send
fn get_iam_policy( &self, _req: GetIamPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Policy>>> + Send
Implements super::client::SchemaService::get_iam_policy.
Sourcefn test_iam_permissions(
&self,
_req: TestIamPermissionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<TestIamPermissionsResponse>>> + Send
fn test_iam_permissions( &self, _req: TestIamPermissionsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<TestIamPermissionsResponse>>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.