pub trait SubscriptionAdmin:
Debug
+ Send
+ Sync {
// Provided methods
fn create_subscription(
&self,
_req: Subscription,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Subscription>>> + Send { ... }
fn get_subscription(
&self,
_req: GetSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Subscription>>> + Send { ... }
fn update_subscription(
&self,
_req: UpdateSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Subscription>>> + Send { ... }
fn list_subscriptions(
&self,
_req: ListSubscriptionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSubscriptionsResponse>>> + Send { ... }
fn delete_subscription(
&self,
_req: DeleteSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn modify_push_config(
&self,
_req: ModifyPushConfigRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn get_snapshot(
&self,
_req: GetSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Snapshot>>> + Send { ... }
fn list_snapshots(
&self,
_req: ListSnapshotsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSnapshotsResponse>>> + Send { ... }
fn create_snapshot(
&self,
_req: CreateSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Snapshot>>> + Send { ... }
fn update_snapshot(
&self,
_req: UpdateSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Snapshot>>> + Send { ... }
fn delete_snapshot(
&self,
_req: DeleteSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn seek(
&self,
_req: SeekRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SeekResponse>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::SubscriptionAdmin.
Application developers may need to implement this trait to mock
client::SubscriptionAdmin. In other use-cases, application developers only
use client::SubscriptionAdmin and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn create_subscription(
&self,
_req: Subscription,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Subscription>>> + Send
fn create_subscription( &self, _req: Subscription, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Subscription>>> + Send
Sourcefn get_subscription(
&self,
_req: GetSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Subscription>>> + Send
fn get_subscription( &self, _req: GetSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Subscription>>> + Send
Sourcefn update_subscription(
&self,
_req: UpdateSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Subscription>>> + Send
fn update_subscription( &self, _req: UpdateSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Subscription>>> + Send
Sourcefn list_subscriptions(
&self,
_req: ListSubscriptionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSubscriptionsResponse>>> + Send
fn list_subscriptions( &self, _req: ListSubscriptionsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListSubscriptionsResponse>>> + Send
Sourcefn delete_subscription(
&self,
_req: DeleteSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_subscription( &self, _req: DeleteSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Sourcefn modify_push_config(
&self,
_req: ModifyPushConfigRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn modify_push_config( &self, _req: ModifyPushConfigRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Sourcefn get_snapshot(
&self,
_req: GetSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Snapshot>>> + Send
fn get_snapshot( &self, _req: GetSnapshotRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Snapshot>>> + Send
Implements super::client::SubscriptionAdmin::get_snapshot.
Sourcefn list_snapshots(
&self,
_req: ListSnapshotsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSnapshotsResponse>>> + Send
fn list_snapshots( &self, _req: ListSnapshotsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListSnapshotsResponse>>> + Send
Implements super::client::SubscriptionAdmin::list_snapshots.
Sourcefn create_snapshot(
&self,
_req: CreateSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Snapshot>>> + Send
fn create_snapshot( &self, _req: CreateSnapshotRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Snapshot>>> + Send
Sourcefn update_snapshot(
&self,
_req: UpdateSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Snapshot>>> + Send
fn update_snapshot( &self, _req: UpdateSnapshotRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Snapshot>>> + Send
Sourcefn delete_snapshot(
&self,
_req: DeleteSnapshotRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_snapshot( &self, _req: DeleteSnapshotRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Sourcefn seek(
&self,
_req: SeekRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SeekResponse>>> + Send
fn seek( &self, _req: SeekRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SeekResponse>>> + Send
Implements super::client::SubscriptionAdmin::seek.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.