pub struct AtLeastOnce { /* private fields */ }Expand description
A handler for at-least-once delivery.
Implementations
Sourceimpl AtLeastOnce
impl AtLeastOnce
Sourcepub fn ack(self)
pub fn ack(self)
Acknowledge the message associated with this handler.
Note that the acknowledgement is best effort. The message may still be redelivered to this client, or another client.
Sourcepub fn nack(self)
pub fn nack(self)
Rejects the message associated with this handler.
Example
use google_cloud_pubsub::model::Message;
fn on_message(m: Message, h: AtLeastOnce) {
println!("Received message: {m:?}");
h.nack();
}The message will be removed from this Subscriber’s lease management.
The service will redeliver this message, possibly to another client.