MessageStream

Struct MessageStream 

pub struct MessageStream { /* private fields */ }
Represents an open subscribe stream.

This is a stream-like struct for serving messages to an application.

Example

let mut stream = client
    .subscribe("projects/my-project/subscriptions/my-subscription")
    .build();
while let Some((m, h)) = stream.next().await.transpose()? {
    println!("Received message m={m:?}");
    h.ack();
}

Implementations

Source

impl MessageStream

pub async fn next(&mut self) -> Option<Result<(Message, Handler)>>

Returns the next message received on this subscription.

Example
while let Some((m, h)) = stream.next().await.transpose()? {
    println!("Received message m={m:?}");
    h.ack();
}

Returns the message data along with a Handler to acknowledge (ack) the message.

If the underlying stream encounters a permanent error, an Error is returned instead.

None represents the end of a stream, but in practice, the stream stays open until it is cancelled or encounters a permanent error.

pub fn into_stream( self, ) -> impl Stream<Item = Result<(Message, Handler)>> + Unpin

Available on crate feature unstable-stream only.

Converts the MessageStream to a futures::Stream.

Example
use futures::TryStreamExt;
let mut stream = stream.into_stream();
while let Some((m, h)) = stream.try_next().await? { /* ... */ }
pub fn shutdown_token(&self) -> ShutdownToken

Returns a shutdown token for the stream.

Example
// Get a shutdown token for the stream.
let shutdown_token = stream.shutdown_token();

// Signal and await a shutdown of the stream.
shutdown_token.shutdown().await;

// The stream stops yielding messages after shutdown is signaled.
assert!(stream.next().await.is_none());

Use this token to signal and/or await shutdown of the stream.

Awaiting a stream shutdown gives the subscriber time to flush its pending acknowledgements, and schedule other messages for redelivery to another client as soon as possible.