pub struct ShutdownToken { /* private fields */ }Expand description
A token to signal and await shutdown of a stream.
Example
use google_cloud_pubsub::subscriber::MessageStream;
async fn sample(stream: MessageStream) {
// Get a shutdown token for the stream.
let token = stream.shutdown_token();
// Signal and await a shutdown of the stream.
token.shutdown().await;
}Implementations
Sourceimpl ShutdownToken
impl ShutdownToken
Sourcepub async fn shutdown(&self)
pub async fn shutdown(&self)
Signal and await a stream shutdown.
Applications should call this to ensure all pending ack/nack RPCs have time to complete before a process exits.
See Subscribe::set_shutdown_behavior to configure the exact
behavior on shutdown.