Google Cloud Client Libraries for Rust - Pub/Sub
WARNING: this crate is under active development. We expect multiple breaking changes in the upcoming releases. Testing is also incomplete, we do not recommend that you use this crate in production. We welcome feedback about the APIs, documentation, missing features, bugs, etc.
This crate contains traits, types, and functions to interact with Pub/Sub. Most applications will use the structs defined in the client module.
For publishing messages:
For receiving messages:
For administrative operations:
NOTE: This crate used to contain a different implementation, with a different surface. @yoshidan generously donated the crate name to Google. Their crate continues to live as gcloud-pubsub.
Features
default-rustls-provider: enabled by default. Use the default rustls crypto provider (aws-lc-rs) for TLS and authentication. Applications with specific requirements for cryptography (such as exclusively using the ring crate) should disable this default and callrustls::crypto::CryptoProvider::install_default().unstable-stream: enable the (unstable) features to convert several types to afuture::Stream.
Modules
- builder
- Request and client builders.
- client
- Clients to interact with Cloud Pub/Sub.
- error
- Custom errors for the Cloud Pub/Sub clients.
- model
- The messages and enums that are part of this client library.
- publisher
- Types related to publishing messages with a Publisher client.
- stub
- Traits to mock the clients in this library.
- subscriber
- Types related to receiving messages with a Subscriber client.
Structs
- Error
- The core error returned by all client libraries.
Type Aliases
- Result
- An alias of std::result::Result where the error is always Error.