Subscriber

Struct Subscriber 

pub struct Subscriber { /* private fields */ }
A Subscriber client for the Cloud Pub/Sub API.

Use this client to receive messages from a pull subscription on a topic.

Example

let client = Subscriber::builder().build().await?;
let mut stream = client
    .subscribe("projects/my-project/subscriptions/my-subscription")
    .build();
while let Some((m, h)) = stream.next().await.transpose()? {
    println!("Received message m={m:?}");
    h.ack();
}

Ordered Delivery

The subscriber returns messages in order if ordered delivery is enabled on the subscription. The client provides the same guarantees as the service.

For more details on how the service works, see:

Exactly-once Delivery

The subscriber does not support exactly-once delivery yet.

If you subscribe to a subscription with exactly-once delivery enabled, the subscriber will deliver you messages with at-least-once semantics. There is no way for you to confirm the acknowledgements from the server. Messages may get redelivered.

Adding support for exactly-once delivery is planned. You can track the progress in google-cloud-rust#3964.

Configuration

To configure a Subscriber use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include:

Pooling and Cloning

Subscriber holds a connection pool internally, it is advised to create one and then reuse it. You do not need to wrap Subscriber in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Subscriber

pub fn builder() -> ClientBuilder

Returns a builder for Subscriber.

Example
let client = Subscriber::builder().build().await?;
pub fn subscribe<T>(&self, subscription: T) -> Subscribe
where T: Into<String>,

Receive messages from a subscription.

The subscription is the full name, in the format of projects/*/subscriptions/*.

Example
let mut stream = client
    .subscribe("projects/my-project/subscriptions/my-subscription")
    .build();
while let Some((m, h)) = stream.next().await.transpose()? {
    println!("Received message m={m:?}");
    h.ack();
}