Module error

Module error 

Custom errors for the Cloud Pub/Sub clients.

Enums

AckError
Represents an error that can occur when acknowledging a message.
PublishError
Represents an error that can occur when publishing a message.