Custom errors for the Cloud Pub/Sub clients.
Enums
- AckError
- Represents an error that can occur when acknowledging a message.
- Publish
Error - Represents an error that can occur when publishing a message.
Custom errors for the Cloud Pub/Sub clients.