#[non_exhaustive]pub enum PublishError {
Rpc(Arc<Error>),
OrderingKeyPaused,
Shutdown,
}Expand description
Represents an error that can occur when publishing a message.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rpc(Arc<Error>)
The underlying RPC failed.
The inner error is wrapped in an Arc because the same error may
affect multiple publish() calls.
OrderingKeyPaused
Publishing is paused because a previous message with the same ordering key failed.
To prevent messages from being sent out of order, the Publisher
paused messages for the ordering key.
To resume publishing, call Publisher::resume_publish.
Shutdown
The operation failed because the Publisher has
been shut down.
Typically this can happen when the application is shutting down. Some background tasks in the client library may be terminated before they can send all the pending messages.