The messages and enums that are part of this client library.
Modules
- ai_
inference - Defines additional types related to AIInference.
- big_
query_ config - Defines additional types related to BigQueryConfig.
- bigtable_
config - Defines additional types related to BigtableConfig.
- cloud_
storage_ config - Defines additional types related to CloudStorageConfig.
- ingestion_
data_ source_ settings - Defines additional types related to IngestionDataSourceSettings.
- message_
transform - Defines additional types related to MessageTransform.
- platform_
logs_ settings - Defines additional types related to PlatformLogsSettings.
- push_
config - Defines additional types related to PushConfig.
- schema
- Defines additional types related to Schema.
- seek_
request - Defines additional types related to SeekRequest.
- subscription
- Defines additional types related to Subscription.
- topic
- Defines additional types related to Topic.
- validate_
message_ request - Defines additional types related to ValidateMessageRequest.
Structs
- AIInference
- Configuration for making inference requests against Vertex AI models.
- BigQuery
Config - Configuration for a BigQuery subscription.
- Bigtable
Config - Configuration for a Bigtable subscription. The Pub/Sub message will be written to a Bigtable row as follows:
- Cloud
Storage Config - Configuration for a Cloud Storage subscription.
- Commit
Schema Request - Request for CommitSchema method.
- Create
Schema Request - Request for the CreateSchema method.
- Create
Snapshot Request - Request for the
CreateSnapshotmethod. - Dead
Letter Policy - Dead lettering is done on a best effort basis. The same message might be dead lettered multiple times.
- Delete
Schema Request - Request for the
DeleteSchemamethod. - Delete
Schema Revision Request - Request for the
DeleteSchemaRevisionmethod. - Delete
Snapshot Request - Request for the
DeleteSnapshotmethod. - Delete
Subscription Request - Request for the DeleteSubscription method.
- Delete
Topic Request - Request for the
DeleteTopicmethod. - Detach
Subscription Request - Request for the DetachSubscription method.
- Detach
Subscription Response - Response for the DetachSubscription method. Reserved for future use.
- Expiration
Policy - A policy that specifies the conditions for resource expiration (i.e., automatic resource deletion).
- GetSchema
Request - Request for the GetSchema method.
- GetSnapshot
Request - Request for the GetSnapshot method.
- GetSubscription
Request - Request for the GetSubscription method.
- GetTopic
Request - Request for the GetTopic method.
- Ingestion
Data Source Settings - Settings for an ingestion data source on a topic.
- Java
ScriptUDF - User-defined JavaScript function that can transform or filter a Pub/Sub message.
- List
Schema Revisions Request - Request for the
ListSchemaRevisionsmethod. - List
Schema Revisions Response - Response for the
ListSchemaRevisionsmethod. - List
Schemas Request - Request for the
ListSchemasmethod. - List
Schemas Response - Response for the
ListSchemasmethod. - List
Snapshots Request - Request for the
ListSnapshotsmethod. - List
Snapshots Response - Response for the
ListSnapshotsmethod. - List
Subscriptions Request - Request for the
ListSubscriptionsmethod. - List
Subscriptions Response - Response for the
ListSubscriptionsmethod. - List
Topic Snapshots Request - Request for the
ListTopicSnapshotsmethod. - List
Topic Snapshots Response - Response for the
ListTopicSnapshotsmethod. - List
Topic Subscriptions Request - Request for the
ListTopicSubscriptionsmethod. - List
Topic Subscriptions Response - Response for the
ListTopicSubscriptionsmethod. - List
Topics Request - Request for the
ListTopicsmethod. - List
Topics Response - Response for the
ListTopicsmethod. - Message
- A message that is published by publishers and consumed by subscribers. The message must contain either a non-empty data field or at least one attribute. Note that client libraries represent this object differently depending on the language. See the corresponding client library documentation for more information. See [quotas and limits] (https://cloud.google.com/pubsub/quotas) for more information about message limits.
- Message
Storage Policy - A policy constraining the storage of messages published to the topic.
- Message
Transform - All supported message transforms types.
- Modify
Push Config Request - Request for the ModifyPushConfig method.
- Platform
Logs Settings - Settings for Platform Logs produced by Pub/Sub.
- Push
Config - Configuration for a push delivery endpoint.
- Retry
Policy - A policy that specifies how Pub/Sub retries message delivery.
- Rollback
Schema Request - Request for the
RollbackSchemamethod. - Schema
- A schema resource.
- Schema
Settings - Settings for validating messages published against a schema.
- Seek
Request - Request for the
Seekmethod. - Seek
Response - Response for the
Seekmethod (this response is empty). - Snapshot
- A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.
- Subscription
- A subscription resource. If none of
push_config,bigquery_config, orcloud_storage_configis set, then the subscriber will pull and ack messages using API methods. At most one of these fields may be set. - Topic
- A topic resource.
- Update
Snapshot Request - Request for the UpdateSnapshot method.
- Update
Subscription Request - Request for the UpdateSubscription method.
- Update
Topic Request - Request for the UpdateTopic method.
- Validate
Message Request - Request for the
ValidateMessagemethod. - Validate
Message Response - Response for the
ValidateMessagemethod. Empty for now. - Validate
Schema Request - Request for the
ValidateSchemamethod. - Validate
Schema Response - Response for the
ValidateSchemamethod. Empty for now.
Enums
- Encoding
- Possible encoding types for messages.
- Schema
View - View of Schema object fields to be returned by GetSchema and ListSchemas.