Module cloud_storage_config

Module cloud_storage_config 

Defines additional types related to CloudStorageConfig.

Structs

AvroConfig
Configuration for writing message data in Avro format. Message payloads and metadata will be written to files as an Avro binary.
TextConfig
Configuration for writing message data in text format. Message payloads will be written to files as raw text, separated by a newline.

Enums

OutputFormat
Defaults to text format.
State
Possible states for a Cloud Storage subscription.