Defines additional types related to CloudStorage.
Structs
- Avro
Format - Configuration for reading Cloud Storage data in Avro binary format. The
bytes of each object will be set to the
datafield of a Pub/Sub message. - PubSub
Avro Format - Configuration for reading Cloud Storage data written via Cloud Storage subscriptions. The data and attributes fields of the originally exported Pub/Sub message will be restored when publishing.
- Text
Format - Configuration for reading Cloud Storage data in text format. Each line of
text as specified by the delimiter will be set to the
datafield of a Pub/Sub message.
Enums
- Input
Format - Defaults to text format.
- State
- Possible states for ingestion from Cloud Storage.