#[non_exhaustive]pub struct AwsMsk {
pub state: State,
pub cluster_arn: String,
pub topic: String,
pub aws_role_arn: String,
pub gcp_service_account: String,
/* private fields */
}Expand description
Ingestion settings for Amazon MSK.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: StateOutput only. An output-only field that indicates the state of the Amazon MSK ingestion source.
cluster_arn: StringRequired. The Amazon Resource Name (ARN) that uniquely identifies the cluster.
topic: StringRequired. The name of the topic in the Amazon MSK cluster that Pub/Sub will import from.
aws_role_arn: StringRequired. AWS role ARN to be used for Federated Identity authentication with Amazon MSK. Check the Pub/Sub docs for how to set up this role and the required permissions that need to be attached to it.
gcp_service_account: StringRequired. The GCP service account to be used for Federated Identity
authentication with Amazon MSK (via a AssumeRoleWithWebIdentity call
for the provided role). The aws_role_arn must be set up with
accounts.google.com:sub equals to this service account number.
Implementations
Sourceimpl AwsMsk
impl AwsMsk
Sourcepub fn set_cluster_arn<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_arn<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_aws_role_arn<T: Into<String>>(self, v: T) -> Self
pub fn set_aws_role_arn<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of gcp_service_account.
Example
let x = AwsMsk::new().set_gcp_service_account("example");Trait Implementations
impl StructuralPartialEq for AwsMsk