#[non_exhaustive]pub struct AzureEventHubs {
pub state: State,
pub resource_group: String,
pub namespace: String,
pub event_hub: String,
pub client_id: String,
pub tenant_id: String,
pub subscription_id: String,
pub gcp_service_account: String,
/* private fields */
}Expand description
Ingestion settings for Azure Event Hubs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: StateOutput only. An output-only field that indicates the state of the Event Hubs ingestion source.
resource_group: StringOptional. Name of the resource group within the azure subscription.
namespace: StringOptional. The name of the Event Hubs namespace.
event_hub: StringOptional. The name of the Event Hub.
client_id: StringOptional. The client id of the Azure application that is being used to authenticate Pub/Sub.
tenant_id: StringOptional. The tenant id of the Azure application that is being used to authenticate Pub/Sub.
subscription_id: StringOptional. The Azure subscription id.
gcp_service_account: StringOptional. The GCP service account to be used for Federated Identity authentication.
Implementations
Sourceimpl AzureEventHubs
impl AzureEventHubs
pub fn new() -> Self
Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
ⓘ
use google_cloud_pubsub::model::ingestion_data_source_settings::azure_event_hubs::State;
let x0 = AzureEventHubs::new().set_state(State::Active);
let x1 = AzureEventHubs::new().set_state(State::EventHubsPermissionDenied);
let x2 = AzureEventHubs::new().set_state(State::PublishPermissionDenied);Sourcepub fn set_resource_group<T: Into<String>>(self, v: T) -> Self
pub fn set_resource_group<T: Into<String>>(self, v: T) -> Self
Sets the value of resource_group.
Example
ⓘ
let x = AzureEventHubs::new().set_resource_group("example");Sourcepub fn set_namespace<T: Into<String>>(self, v: T) -> Self
pub fn set_namespace<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_event_hub<T: Into<String>>(self, v: T) -> Self
pub fn set_event_hub<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_client_id<T: Into<String>>(self, v: T) -> Self
pub fn set_client_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_tenant_id<T: Into<String>>(self, v: T) -> Self
pub fn set_tenant_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_subscription_id<T: Into<String>>(self, v: T) -> Self
pub fn set_subscription_id<T: Into<String>>(self, v: T) -> Self
Sets the value of subscription_id.
Example
ⓘ
let x = AzureEventHubs::new().set_subscription_id("example");Sourcepub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of gcp_service_account.
Example
ⓘ
let x = AzureEventHubs::new().set_gcp_service_account("example");Trait Implementations
Sourceimpl Clone for AzureEventHubs
impl Clone for AzureEventHubs
Sourcefn clone(&self) -> AzureEventHubs
fn clone(&self) -> AzureEventHubs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AzureEventHubs
impl Debug for AzureEventHubs
Sourceimpl Default for AzureEventHubs
impl Default for AzureEventHubs
Sourcefn default() -> AzureEventHubs
fn default() -> AzureEventHubs
Returns the “default value” for a type. Read more
Sourceimpl Message for AzureEventHubs
impl Message for AzureEventHubs
Sourceimpl PartialEq for AzureEventHubs
impl PartialEq for AzureEventHubs
impl StructuralPartialEq for AzureEventHubs