#[non_exhaustive]pub struct ConfluentCloud {
pub state: State,
pub bootstrap_server: String,
pub cluster_id: String,
pub topic: String,
pub identity_pool_id: String,
pub gcp_service_account: String,
/* private fields */
}Expand description
Ingestion settings for Confluent Cloud.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: StateOutput only. An output-only field that indicates the state of the Confluent Cloud ingestion source.
bootstrap_server: StringRequired. The address of the bootstrap server. The format is url:port.
cluster_id: StringRequired. The id of the cluster.
topic: StringRequired. The name of the topic in the Confluent Cloud cluster that Pub/Sub will import from.
identity_pool_id: StringRequired. The id of the identity pool to be used for Federated Identity authentication with Confluent Cloud. See https://docs.confluent.io/cloud/current/security/authenticate/workload-identities/identity-providers/oauth/identity-pools.html#add-oauth-identity-pools.
gcp_service_account: StringRequired. The GCP service account to be used for Federated Identity
authentication with identity_pool_id.
Implementations
Sourceimpl ConfluentCloud
impl ConfluentCloud
pub fn new() -> Self
Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_pubsub::model::ingestion_data_source_settings::confluent_cloud::State;
let x0 = ConfluentCloud::new().set_state(State::Active);
let x1 = ConfluentCloud::new().set_state(State::ConfluentCloudPermissionDenied);
let x2 = ConfluentCloud::new().set_state(State::PublishPermissionDenied);Sourcepub fn set_bootstrap_server<T: Into<String>>(self, v: T) -> Self
pub fn set_bootstrap_server<T: Into<String>>(self, v: T) -> Self
Sets the value of bootstrap_server.
Example
let x = ConfluentCloud::new().set_bootstrap_server("example");Sourcepub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_identity_pool_id<T: Into<String>>(self, v: T) -> Self
pub fn set_identity_pool_id<T: Into<String>>(self, v: T) -> Self
Sets the value of identity_pool_id.
Example
let x = ConfluentCloud::new().set_identity_pool_id("example");Sourcepub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_gcp_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of gcp_service_account.
Example
let x = ConfluentCloud::new().set_gcp_service_account("example");Trait Implementations
Sourceimpl Clone for ConfluentCloud
impl Clone for ConfluentCloud
Sourcefn clone(&self) -> ConfluentCloud
fn clone(&self) -> ConfluentCloud
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ConfluentCloud
impl Debug for ConfluentCloud
Sourceimpl Default for ConfluentCloud
impl Default for ConfluentCloud
Sourcefn default() -> ConfluentCloud
fn default() -> ConfluentCloud
Sourceimpl Message for ConfluentCloud
impl Message for ConfluentCloud
Sourceimpl PartialEq for ConfluentCloud
impl PartialEq for ConfluentCloud
impl StructuralPartialEq for ConfluentCloud