pub enum ShutdownBehavior {
WaitForProcessing,
NackImmediately,
}Expand description
The behavior on shutdown.
Variants
WaitForProcessing
The subscriber stops reading from the underlying gRPC stream.
The subscriber continues to accept acknowledgements for messages it has delivered to the application. The subscriber continues to extend leases for these messages while it waits on the application to ack/nack them.
The shutdown is complete when all message handles delivered to the application have been consumed, and all pending ack/nack RPCs have completed.
NackImmediately
The subscriber stops reading from the underlying gRPC stream.
The subscriber stops accepting acknowledgements from the application. The subscriber sends all pending acknowledgements to the server. The subscriber nacks all other messages under lease management.
The shutdown is complete when all pending ack/nack RPCs have completed.