pub struct ExactlyOnce { /* private fields */ }Expand description
A handler for exactly-once delivery.
Implementations
Sourceimpl ExactlyOnce
impl ExactlyOnce
Sourcepub async fn confirmed_ack(self) -> Result<(), AckError>
pub async fn confirmed_ack(self) -> Result<(), AckError>
Strongly acknowledge the message associated with this handler.
use google_cloud_pubsub::model::Message;
async fn on_message(m: Message, h: ExactlyOnce) {
match h.confirmed_ack().await {
Ok(()) => println!("Confirmed ack for message={m:?}. The message will not be redelivered."),
Err(e) => println!("Failed to confirm ack for message={m:?} with error={e:?}"),
}
}If the result is an Ok, the message is guaranteed not to be delivered
again.
If the result is an Err, the message may be redelivered, but this is
not guaranteed. If no redelivery occurs a sufficient interval after an
error, the acknowledgement likely succeeded.