pub struct MessageStream { /* private fields */ }Expand description
Represents an open subscribe stream.
This is a stream-like struct for serving messages to an application.
Example
let mut stream = client
.subscribe("projects/my-project/subscriptions/my-subscription")
.build();
while let Some((m, h)) = stream.next().await.transpose()? {
println!("Received message m={m:?}");
h.ack();
}Implementations
Sourceimpl MessageStream
impl MessageStream
Sourcepub async fn next(&mut self) -> Option<Result<(Message, Handler)>>
pub async fn next(&mut self) -> Option<Result<(Message, Handler)>>
Returns the next message received on this subscription.
Example
while let Some((m, h)) = stream.next().await.transpose()? {
println!("Received message m={m:?}");
h.ack();
}Returns the message data along with a Handler to acknowledge (ack) the message.
If the underlying stream encounters a permanent error, an Error is
returned instead.
None represents the end of a stream, but in practice, the stream stays
open until it is cancelled or encounters a permanent error.
Sourcepub fn into_stream(
self,
) -> impl Stream<Item = Result<(Message, Handler)>> + Unpin
Available on crate feature unstable-stream only.
pub fn into_stream( self, ) -> impl Stream<Item = Result<(Message, Handler)>> + Unpin
unstable-stream only.Converts the MessageStream to a futures::Stream.
Example
use futures::TryStreamExt;
let mut stream = stream.into_stream();
while let Some((m, h)) = stream.try_next().await? { /* ... */ }Trait Implementations